# Tiny emitter
![example workflow](https://github.com/skilef/tiny-emitter/actions/workflows/python-package.yml/badge.svg)

A lightweight event emitter for Python.

## Setup
```shell
pip install tiny_emitter
```

## Running tests
```shell
pytest
```

## TODO

- [ ] Write unit tests